@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp
-version: 3.2.4
-id: warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
-key: warp_3URFxxGLnVl62M4QPEPtbo
+version: 3.2.6
+id: warp-3.2.6-0273436dc44d76eb20f09024e8daa00c
+key: warp_5R3meb2HrPoIAnUzhu4NTK
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -27,6 +27,7 @@ hidden-modules: Network.Wai.Handler.Warp.Buffer
                 Network.Wai.Handler.Warp.FileInfoCache
                 Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                 Network.Wai.Handler.Warp.HTTP2.EncodeFrame
+                Network.Wai.Handler.Warp.HTTP2.File
                 Network.Wai.Handler.Warp.HTTP2.HPACK
                 Network.Wai.Handler.Warp.HTTP2.Manager
                 Network.Wai.Handler.Warp.HTTP2.Receiver
@@ -35,8 +36,9 @@ hidden-modules: Network.Wai.Handler.Warp.Buffer
                 Network.Wai.Handler.Warp.HTTP2.Types
                 Network.Wai.Handler.Warp.HTTP2.Worker
                 Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
-                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.ReadInt
-                Network.Wai.Handler.Warp.Recv Network.Wai.Handler.Warp.Request
+                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
+                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
+                Network.Wai.Handler.Warp.Request
                 Network.Wai.Handler.Warp.RequestHeader
                 Network.Wai.Handler.Warp.Response
                 Network.Wai.Handler.Warp.ResponseHeader
@@ -47,34 +49,34 @@ hidden-modules: Network.Wai.Handler.Warp.Buffer
                 Network.Wai.Handler.Warp.WithApplication Paths_warp
                 Network.Wai.Handler.Warp.MultiMap
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.4
-hs-libraries: HSwarp-3.2.4-3URFxxGLnVl62M4QPEPtbo
+import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.6
+hs-libraries: HSwarp-3.2.6-5R3meb2HrPoIAnUzhu4NTK
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
-    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
+    auto-update-0.1.4-5802161b0d99b2a30d57c95848e07a31
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    http2-1.5.4-82dccce60697e4ed1d56153dae3e45f1
+    http-date-0.0.6.1-4ea0001d3f50118f98db684749e0642e
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    http2-1.6.0-d2e1144627a6b24ef6e2d1bd89ea06c3
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
+    simple-sendfile-0.2.22-5543b22c4382748239d6fed42d7bf1f0
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
-    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
 haddock-html: /usr/share/doc/haskell-warp/html
